@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'heat' do
   let :pre_condition do
-    "class { '::heat::keystone::authtoken':
+    "class { 'heat::keystone::authtoken':
        password => 'secretpassword',
      }"
   end
@@ -10,8 +10,6 @@ describe 'heat' do
   let :params do
     {
       :package_ensure        => 'present',
-      :database_connection   => 'mysql+pymysql://user@host/database',
-      :database_idle_timeout => 3600,
       :flavor                => 'keystone',
       :heat_clients_url      => '<SERVICE DEFAULT>',
       :purge_config          => false,
@@ -34,7 +32,8 @@ describe 'heat' do
     context 'with rabbit heartbeat configured' do
       before { params.merge!(
         :rabbit_heartbeat_timeout_threshold => '60',
-        :rabbit_heartbeat_rate => '10' ) }
+        :rabbit_heartbeat_rate => '10', 
+        :rabbit_heartbeat_in_pthread => true ) }
       it_configures 'a heat base installation'
       it_configures 'rabbit with heartbeat configured'
     end
@@ -88,6 +87,10 @@ describe 'heat' do
       is_expected.to contain_heat_config('DEFAULT/max_template_size').with_value('<SERVICE DEFAULT>')
     end
 
+    it 'configures max_stacks_per_tenant' do
+      is_expected.to contain_heat_config('DEFAULT/max_stacks_per_tenant').with_value('<SERVICE DEFAULT>')
+    end
+
     it 'configures max_json_body_size' do
       is_expected.to contain_heat_config('DEFAULT/max_json_body_size').with_value('<SERVICE DEFAULT>')
     end
@@ -160,6 +163,7 @@ describe 'heat' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
         :rabbit_use_ssl     => '<SERVICE DEFAULT>',
         :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
@@ -198,6 +202,7 @@ describe 'heat' do
     end
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true) }
   end
 
   shared_examples_for 'with SSL enabled with kombu' do
@@ -383,7 +388,6 @@ describe 'heat' do
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_heat_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
@@ -411,7 +415,6 @@ describe 'heat' do
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ca.cert') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/certfile') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/key') }
-      it { is_expected.to contain_heat_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
